PromptTemplate class

Annotations
  • @freezed

Constructors

PromptTemplate({required String label, @Default.new('') String systemMessage, required String promptTemplate, required String prompt, @Default.new('') String output, @Default.new(2048) int contextSize, @Default.new(<String>[]) List<String> verifiedSignatures})
const
factory
PromptTemplate.alpaca2()
factory
PromptTemplate.alpaca2Chinese()
factory
PromptTemplate.alpacaInstructOnly()
factory
PromptTemplate.chatML()
factory
PromptTemplate.fromJson(Map<String, dynamic> json)
factory
PromptTemplate.llama2Chat()
factory
PromptTemplate.nothing()
factory
PromptTemplate.story()
factory
PromptTemplate.synthia()
factory

Properties

contextSize → int
no setterinherited
copyWith → $PromptTemplateCopyWith<PromptTemplate>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
label → String
no setterinherited
output → String
no setterinherited
prompt → String
no setterinherited
promptTemplate → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
systemMessage → String
no setterinherited
verifiedSignatures → List<String>
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

all → List<PromptTemplate>
no setter